import {Component, ComponentInterface, Prop, h} from '@stencil/core';
import {CtaLinkButtonVariants} from '../../utils/utils';

@Component({
  tag: 'hy-cta-link',
  styleUrl: 'cta-link.scss',
  shadow: true
})
export class CtaLink implements ComponentInterface {
  @Prop() linkContent: string = '';
  @Prop() url?: string;
  @Prop() scLabel?: string;
  @Prop() isExternal: boolean = false;

  render() {
    const ctaLinkVariant = CtaLinkButtonVariants.default;
    const classAttributes = ['hy-cta-link', ctaLinkVariant].join(' ');

    const containerClassAttributes = ['hy-cta-link-container'].join(' ');

    const textClassAttributes = ['text'].join(' ');
    const iconClassAttributes = ['link-icon'].join(' ');

    const target = this.isExternal ? '_blank' : '_self';

    return (
      <span class={containerClassAttributes}>
        <a aria-label={this.scLabel} class={classAttributes} href={this.url} target={target}>
          <span class={textClassAttributes}>{this.linkContent.length === 0 ? <slot /> : this.linkContent}</span>
          <span class={iconClassAttributes}>
            <hy-icon icon={'hy-icon-arrow-right'} size={48} />
          </span>
        </a>
      </span>
    );
  }
}
